@@ -2,7 +2,7 @@
 # Author: Pranav Khade, Iowa State University
 # Please read the project licence file for the Copyrights.
 
-"""The 'packman' is a collection of subpackages built on the packman.molecule API.
+"""The py-PACKMAN is a collection of subpackages built on the packman.molecule API.
 
 Please check the corresponding packages and tutorials for more information about the package use.
 """
@@ -15,4 +15,4 @@ from .utilities import *
 
 
 #VERSION CHANGE HERE CHANGES IT IN docs AND setup.py
-__version__='1.3.1'
\ No newline at end of file
+__version__='1.3.2'
\ No newline at end of file
